﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using ProtoBuf;
namespace Server
{
    public static class Msg
    {
        [Serializable]
        [ProtoContract]
        public class V3
        {
            [ProtoMember(1)]
            public float x;
            [ProtoMember(2)]
            public float y;
            [ProtoMember(3)]
            public float z;
            public V3() { }
            public V3(float x, float y, float z) {
                this.x = x; this.y = y; this.z = z;
            }
            public V3(V3 v) {
                x = v.x;
                y = v.y;
                z = v.z;
            }
            public override string ToString() {
                return "x: " + x + " y:" + y + " z:" + z;
            }
            public static V3 operator +(V3 v1, V3 v2) {
                return new V3(v1.x + v2.x, v1.y + v2.y, v1.z + v2.z);
            }
            public static V3 operator -(V3 v1, V3 v2) {
                return new V3(v1.x - v2.x, v1.y - v2.y, v1.z - v2.z);
            }
        }
        [Serializable]
        [ProtoContract]
        public class V4
        {
            [ProtoMember(1)]
            public float x;
            [ProtoMember(2)]
            public float y;
            [ProtoMember(3)]
            public float z;
            [ProtoMember(4)]
            public float w;
            public V4() { }
            public V4(float x, float y, float z, float w) {
                this.x = x; this.y = y; this.z = z; this.w = w;
            }
            public V4(V4 v) {
                x = v.x; y = v.y; z = v.z; w = v.w;
            }

            public override string ToString() {
                return "x: " + x + " y:" + y + " z:" + z + " w:" + w;
            }
        }
        // Move:	SessionID		Force	BodyPosition	BodyRotation	TurretBaseRotation	TurretRotation

        [Serializable]
        [ProtoContract]
        public class Move
        {
            [ProtoMember(1)]
            public readonly string SessionID = "";
            [ProtoMember(2)]
            public float Force = -1;
            [ProtoMember(3)]
            public V3 BodyPosition;
            [ProtoMember(4)]
            public V4 BodyRotation;
            [ProtoMember(5)]
            public V4 TurretBaseRotation;
            [ProtoMember(6)]
            public V4 TurretCannonRotation;
            [ProtoMember(7)]
            public float hp = 100.0f;
            public Move() { }
            public Move(string SessionID, float Force, V3 BodyPosition, V4 BodyRotation, V4 TurretBaseRotation, V4 TurretCannonRotation ) {
                this.SessionID = SessionID;
                this.Force = Force;
                this.BodyPosition = BodyPosition;
                this.BodyRotation = BodyRotation;
                this.TurretBaseRotation = TurretBaseRotation;
                this.TurretCannonRotation = TurretCannonRotation;
            }
            public Move(Move m) {
                if (m == null)
                    return;
                BodyPosition = new V3(m.BodyPosition);
                BodyRotation = new V4(m.BodyRotation);
                TurretBaseRotation = new V4(m.TurretBaseRotation);
                TurretCannonRotation = new V4(m.TurretCannonRotation);
                Force = m.Force;
            }

        }
        public enum WeaponType { Default, Mine, TeleForce };

        [Serializable]
        [ProtoContract]
        public class Shoot
        {
            [ProtoMember(1)]
            public string SessionID = "";
            [ProtoMember(2)]
            public int BulletID = -1;
            [ProtoMember(3)]
            public WeaponType weapon = WeaponType.Default;


            public Shoot() { }
            public Shoot(string SessionID, int BulletID, WeaponType weaponType) {
                this.SessionID = SessionID;
                this.BulletID = BulletID;
                this.weapon = weaponType;
            }
        }
        [Serializable]
        [ProtoContract]
        public class Hit
        {
            [ProtoMember(1)]
            public string SessionID = "";   // TODO TODO: Only hitting player name - no need for session ID
            [ProtoMember(2)]
            public int BulletID = -1;
            [ProtoMember(3)]
            public string HittedTankID = "";
            [ProtoMember(4)]
            public string ReporterID = "";
            public Hit() { }
            public Hit(string SessionID, int BulletID, string HittedTankID, string ReporterID) {
                this.SessionID = SessionID;
                this.BulletID = BulletID;
                this.HittedTankID = HittedTankID;
                this.ReporterID = ReporterID;
            }
        }
        [Serializable]
        [ProtoContract]
        public class ShootResponse
        {
            [ProtoMember(1)]
            public string playerName = "";
            [ProtoMember(2)]
            public int BulletID = -1;
            [ProtoMember(3)]
            public WeaponType weapon = WeaponType.Default;

            public ShootResponse() { }
            public ShootResponse(string playerName, int BulletID) {
                this.playerName = playerName;
                this.BulletID = BulletID;
            }
        }

        [Serializable]
        [ProtoContract]
        public class LoginResponse
        {
            [ProtoMember(1)]
            public string playerName = "";
            [ProtoMember(2)]
            public string sessionID = "";

            public LoginResponse() { }
            public LoginResponse(string playerName, string sessionID) {
                this.playerName = playerName;
                this.sessionID = sessionID;
            }
        }

        [Serializable]
        [ProtoContract]
        public class PlayerJoin
        {
            [ProtoMember(1)]
            public string playerName = "";
            public PlayerJoin() { }
            public PlayerJoin(string playerName) { this.playerName = playerName; }
        }
        [Serializable]
        [ProtoContract]
        public class Kill
        {
            [ProtoMember(1)]
            public string dead = "";
            [ProtoMember(2)]
            public string killer = "";
            public Kill() { }
            public Kill(string dead, string killer) {
                this.dead = dead;
                this.killer = killer;
            }
        }

    }
}










