﻿using UnityEngine;
using System.Collections;

public class SwipeDetector : MonoBehaviour
{

    private const int mMessageWidth = 200;
    private const int mMessageHeight = 64;

    private readonly Vector2 mXAxis = new Vector2(1, 0);
    private readonly Vector2 mYAxis = new Vector2(0, 1);

    private readonly string[] mMessage = {
        "",
        "Swipe Left",
        "Swipe Right",
        "Swipe Top",
        "Swipe Bottom"
    };

    [Range(0,4)]
    public static int mMessageIndex = 0;

    public static float velocitySwipe = 0.0f;

    // The angle range for detecting swipe
    private const float mAngleRange = 30;

    // To recognize as swipe user should at lease swipe for this many pixels
    private const float mMinSwipeDist = 0.3f;

    // To recognize as a swipe the velocity of the swipe
    // should be at least mMinVelocity
    // Reduce or increase to control the swipe speed
    private const float mMinVelocity = 0.7f;

    private Vector2 mStartPosition;
    private float mSwipeStartTime;

    //public static int SwipeDetect { return mMessageIndex; }

    // Use this for initialization
    void Start()
    {
    }

    // Update is called once per frame
    void Update()
    {

        // Mouse button down, possible chance for a swipe
        if (/*Input.GetMouseButtonDown(0) ||*/ GvrController.TouchDown)
        {
            // Record start time and position
            mStartPosition = GvrController.TouchPos;//new Vector2(Input.mousePosition.x,Input.mousePosition.y);
            mSwipeStartTime = Time.time;
            //Debug.Log("TouchDown");

        }

        // Mouse button up, possible chance for a swipe
        if (/*Input.GetMouseButtonUp(0) ||*/ GvrController.TouchUp)
        {
            float deltaTime = Time.time - mSwipeStartTime;

            Vector2 endPosition = GvrController.TouchPos;//new Vector2(Input.mousePosition.x,Input.mousePosition.y);
            Vector2 swipeVector = endPosition - mStartPosition;
            //Debug.Log("TouchUp");

            float velocity = swipeVector.magnitude / deltaTime;
            //Debug.Log(velocity);
            if (velocity > mMinVelocity &&
                swipeVector.magnitude > mMinSwipeDist)
            {
                // if the swipe has enough velocity and enough distance
                velocitySwipe = velocity;

                swipeVector.Normalize();

                float angleOfSwipe = Vector2.Dot(swipeVector, mXAxis);
                angleOfSwipe = Mathf.Acos(angleOfSwipe) * Mathf.Rad2Deg;
                //Debug.Log(angleOfSwipe);
                // Detect left and right swipe
                if (angleOfSwipe < mAngleRange)
                {
                    OnSwipeRight();
                }
                else if ((180.0f - angleOfSwipe) < mAngleRange)
                {
                    OnSwipeLeft();
                }
                else
                {
                    // Detect top and bottom swipe
                    angleOfSwipe = Vector2.Dot(swipeVector, mYAxis);
                    angleOfSwipe = Mathf.Acos(angleOfSwipe) * Mathf.Rad2Deg;
                    if (angleOfSwipe < mAngleRange)
                    {
                        OnSwipeBottom();
                        
                    }
                    else if ((180.0f - angleOfSwipe) < mAngleRange)
                    {
                        OnSwipeTop();
                    }
                    else
                    {
                        mMessageIndex = 0;
                    }
                }
            }
        }
        //mMessageIndex = 0;
    }

    /*void OnGUI()
    {
        // Display the appropriate message
        GUI.Label(new Rect((Screen.width - mMessageWidth) / 2,
                           (Screen.height - mMessageHeight) / 2,
                            mMessageWidth, mMessageHeight),
                  mMessage[mMessageIndex]);
    }*/

    private void OnSwipeLeft()
    {
        mMessageIndex = 1;
        Debug.Log("OnSwipeLeft");
    }

    private void OnSwipeRight()
    {
        mMessageIndex = 2;
        Debug.Log("OnSwipeRight");
    }

    private void OnSwipeTop()
    {
        mMessageIndex = 3;
        Debug.Log("OnSwipeTop");
    }

    private void OnSwipeBottom()
    {
        mMessageIndex = 4;
        Debug.Log("OnSwipeBottom");
    }
}